@@ -1,6 +1,6 @@
 # Tests for SecretStorage
-# Author: Dmitry Shachnev, 2013
-# License: BSD
+# Author: Dmitry Shachnev, 2013-2018
+# License: 3-clause BSD, see LICENSE file
 
 # Various exception tests
 
@@ -12,25 +12,24 @@ class ExceptionsTest(unittest.TestCase):
 	"""A test case that ensures that all SecretStorage exceptions
 	are raised correctly."""
 
-	@classmethod
-	def setUpClass(cls):
-		cls.bus = secretstorage.dbus_init(main_loop=False)
-		cls.collection = secretstorage.get_any_collection(cls.bus)
+	def setUp(self) -> None:
+		self.connection = secretstorage.dbus_init()
+		self.collection = secretstorage.get_any_collection(self.connection)
 
-	def test_double_deleting(self):
+	def tearDown(self) -> None:
+		self.connection.close()
+
+	def test_double_deleting(self) -> None:
 		item = self.collection.create_item('MyItem',
 			{'application': 'secretstorage-test'}, b'pa$$word')
 		item.delete()
 		self.assertRaises(ItemNotFoundException, item.delete)
 
-	def test_non_existing_item(self):
+	def test_non_existing_item(self) -> None:
 		self.assertRaises(ItemNotFoundException, secretstorage.Item,
-			self.bus, '/not/existing/path')
+			self.connection, '/not/existing/path')
 
-	def test_non_existing_collection(self):
+	def test_non_existing_collection(self) -> None:
 		self.assertRaises(ItemNotFoundException,
 			secretstorage.get_collection_by_alias,
-			self.bus, 'non-existing-alias')
-
-if __name__ == '__main__':
-	unittest.main()
+			self.connection, 'non-existing-alias')
