@@ -1,6 +1,6 @@
 # Tests for SecretStorage
-# Author: Dmitry Shachnev, 2013
-# License: BSD
+# Author: Dmitry Shachnev, 2013-2018
+# License: 3-clause BSD, see LICENSE file
 
 # This file tests the secretstorage.Collection class.
 
@@ -16,32 +16,36 @@ class ItemTest(unittest.TestCase):
 	"""A test case that tests that all common methods of Item
 	class work and do not crash."""
 
-	@classmethod
-	def setUpClass(cls):
-		cls.bus = dbus_init(main_loop=False)
-		cls.collection = get_any_collection(cls.bus)
-		cls.created_timestamp = time.time()
-		cls.item = cls.collection.create_item('My item', ATTRIBUTES,
+	def setUp(self) -> None:
+		self.connection = dbus_init()
+		self.collection = get_any_collection(self.connection)
+		self.created_timestamp = time.time()
+		self.item = self.collection.create_item('My item', ATTRIBUTES,
 			b'pa$$word')
-		cls.other_item = cls.collection.create_item('My item',
-			ATTRIBUTES, '', content_type='data/null')
+		self.other_item = self.collection.create_item('My item',
+			ATTRIBUTES, b'', content_type='data/null')
 
-	def test_equal(self):
+	def tearDown(self) -> None:
+		self.item.delete()
+		self.other_item.delete()
+		self.connection.close()
+
+	def test_equal(self) -> None:
 		self.assertEqual(self.item, self.item)
 		self.assertNotEqual(self.item, self.other_item)
 		self.assertEqual(self.other_item, self.other_item)
 
-	def test_searchable(self):
+	def test_searchable(self) -> None:
 		search_results = self.collection.search_items(ATTRIBUTES)
 		self.assertIn(self.item, search_results)
-		search_results = search_items(self.bus, ATTRIBUTES)
+		search_results = search_items(self.connection, ATTRIBUTES)
 		self.assertIn(self.item, search_results)
 
-	def test_item_in_all_items(self):
+	def test_item_in_all_items(self) -> None:
 		all_items = self.collection.get_all_items()
 		self.assertIn(self.item, all_items)
 
-	def test_attributes(self):
+	def test_attributes(self) -> None:
 		attributes = self.item.get_attributes()
 		for key in ATTRIBUTES:
 			self.assertEqual(ATTRIBUTES[key], attributes[key])
@@ -51,37 +55,41 @@ class ItemTest(unittest.TestCase):
 			self.assertEqual(NEW_ATTRIBUTES[key], attributes[key])
 		self.item.set_attributes(ATTRIBUTES)
 
-	def test_label(self):
+	def test_label(self) -> None:
 		self.assertEqual(self.item.get_label(), 'My item')
 		self.item.set_label('Hello!')
 		self.assertEqual(self.item.get_label(), 'Hello!')
 
-	def test_secret(self):
+	def test_secret(self) -> None:
 		self.assertEqual(self.item.get_secret(), b'pa$$word')
 		self.item.set_secret(b'newpa$$word')
 		self.assertIsInstance(self.item.get_secret(), bytes)
 		self.assertEqual(self.item.get_secret(), b'newpa$$word')
 		self.assertEqual(self.other_item.get_secret(), b'')
 
-	def test_secret_content_type(self):
+	def test_secret_wrong_type(self) -> None:
+		# string passwords are encoded as bytes
+		self.item.set_secret('test тест')  # type: ignore
+		self.assertEqual(self.item.get_secret(),
+		                 'test тест'.encode('utf-8'))
+		# other types are not allowed
+		with self.assertRaises(TypeError):
+			self.item.set_secret(None)  # type: ignore
+
+	def test_secret_content_type(self) -> None:
 		self.assertEqual(self.item.get_secret_content_type(), 'text/plain')
 		# The check below fails in gnome-keyring because it doesn't really
 		# support content types.
 		#self.assertEqual(self.other_item.get_secret_content_type(), 'data/null')
 
-	def test_modified(self):
+	def test_modified(self) -> None:
 		now = time.time()
 		modified = self.item.get_modified()
 		self.assertAlmostEqual(now, modified, places=-1)
 
-	def test_created(self):
+	def test_created(self) -> None:
 		created = self.item.get_created()
 		self.assertAlmostEqual(self.created_timestamp, created, places=-1)
 
-	@classmethod
-	def tearDownClass(cls):
-		cls.item.delete()
-		cls.other_item.delete()
-
-if __name__ == '__main__':
-	unittest.main()
+	def test_unlock(self) -> None:
+		self.item.unlock()
